@@ -6,6 +6,8 @@ class GFeedsViewModeMenu(Gtk.PopoverMenu):
         super().__init__(**kwargs)
         self.set_modal(True)
         self.set_relative_to(relative_to)
+        relative_to.set_popover(self)
+        relative_to.set_sensitive(False)
         self.builder = Gtk.Builder.new_from_resource(
             '/org/gabmus/gfeeds/ui/extra_popover_menu.glade'
         )
